@@ -32,11 +32,18 @@ class QSqlQuery;
 #include "entities.h"
 #include "notificationcollector.h"
 
-class OrgKdeAkonadiResourceInterface;
+class OrgFreedesktopAkonadiResourceInterface;
+namespace org {
+  namespace freedesktop {
+    namespace Akonadi {
+      typedef ::OrgFreedesktopAkonadiResourceInterface Resource;
+    }
+  }
+}
+
 
 namespace Akonadi {
 
-class FetchQuery;
 class NotificationCollector;
 
 /**
@@ -250,7 +257,7 @@ protected:
     void debugLastDbError( const char* actionDescription ) const;
     void debugLastQueryError( const QSqlQuery &query, const char* actionDescription ) const;
   public:
-    void retrieveDataFromResource( qint64 uid, const QByteArray& remote_id,
+    void retrieveDataFromResource( qint64 uid, const QByteArray& remote_id, const QByteArray& mimeType,
                                          const QString &resource, const QStringList &parts );
     void triggerCollectionSync( const Location &location );
 
@@ -280,7 +287,7 @@ protected:
     /**
       Returns the D-Bus interface of the given resource.
     */
-    OrgKdeAkonadiResourceInterface* resourceInterface( const QString &res );
+    org::freedesktop::Akonadi::Resource *resourceInterface( const QString &res );
 
 private:
     QString m_connectionName;
@@ -303,7 +310,7 @@ private:
     static QString mDbConnectionOptions;
 
     // resource dbus interface cache
-    QHash<QString, OrgKdeAkonadiResourceInterface*> mResourceInterfaceCache;
+    QHash<QString, org::freedesktop::Akonadi::Resource*> mResourceInterfaceCache;
 };
 
 }
